-- ToME - Tales of Maj'Eyal
-- Copyright (C) 2009, 2010, 2011, 2012 Nicolas Casalini
--
-- This program is free software: you can redistribute it and/or modify
-- it under the terms of the GNU General Public License as published by
-- the Free Software Foundation, either version 3 of the License, or
-- (at your option) any later version.
--
-- This program is distributed in the hope that it will be useful,
-- but WITHOUT ANY WARRANTY; without even the implied warranty of
-- MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-- GNU General Public License for more details.
--
-- You should have received a copy of the GNU General Public License
-- along with this program.  If not, see <http://www.gnu.org/licenses/>.
--
-- Nicolas Casalini "DarkGod"
-- darkgod@te4.org

load("/data/general/npcs/thieve.lua")

local Talents = require("engine.interface.ActorTalents")

newEntity{ define_as = "ARMORY_MASTER",
	type = "humanoid", subtype = "human", unique = true,
	name = "Scarface, the bandid leader",
	display = "p", color={r=60,g=15,b=15},
	desc = [[A tall man dressed in a black coat. He has a big scar on his forehead. It reminds you of a movie you once saw.]],
	level_range = {5, nil}, exp_worth = 1,
	max_life = resolvers.rngavg(90,100), life_rating = 14,
	max_stamina = 85,
	stamina_regen = 5,
	stats = { str=20, dex=10, cun=8, mag=10, con=20 },
	rank = 4,
	size_category = 3,
	infravision = 10,
	instakill_immune = 1,
	move_others=true,
	open_door = true,

	body = { INVEN = 10, MAINHAND=1, OFFHAND=1, BODY=1 },

	resolvers.equip{
		{type="weapon", subtype="longsword", autoreq=true, force_drop=true, tome_drops="boss"},
		{type="weapon", subtype="dagger", autoreq=true, force_drop=true, tome_drops="boss"},
		{type="armor", subtype="light", autoreq=true, force_drop=true, tome_drops="boss"}
	},
	resolvers.drops{chance=100, nb=2, {type="money"} },
	resolvers.drops{chance=100, nb=3, {tome_drops="boss"} },

	autolevel = "warrior",

	ai = "tactical", ai_state = { talent_in=3, ai_move="move_astar", },
	ai_tactic = resolvers.tactic"melee",

	resolvers.talents{
		[Talents.T_KNOCKBACK]=3,
	},

	seen_by = function(self, who)
		if not game.party:hasMember(who) then return end
		self.seen_by = nil
		local emotes = {"You wanna play rough? Ok. Say hello, to my little friend.","What are we gonna do now? We go to war! That's what we we’re gonna do!", "Say goodnight to the bad guy.", "In this country, you gotta make the money first.", "Never underestimate the other guy's greed."}
		local randomemote = rng.table(emotes)
		self:doEmote(randomemote, 60)
	end,
}


newEntity{
	define_as = "BASE_NPC_HUMAN_WARRIOR",
	type = "humanoid", subtype = "human",
	display = "p", color=colors.UMBER,
	body = { INVEN = 10, MAINHAND=1, OFFHAND=1, BODY=1, QUIVER=1 },
	resolvers.drops{chance=20, nb=1, {} },
	resolvers.drops{chance=10, nb=1, {type="money"} },
	infravision = 10,
	lite = 1,
	life_rating = 15,
	rank = 2,
	size_category = 3,
	open_door = true,
	resolvers.racial(),
	resolvers.talents{ [Talents.T_ARMOUR_TRAINING]=5, [Talents.T_WEAPON_COMBAT]={base=1, every=10, max=5}, [Talents.T_WEAPONS_MASTERY]={base=1, every=10, max=5} },
	autolevel = "warrior",
	ai = "dumb_talented_simple", ai_state = { ai_move="move_dmap", talent_in=3, },
	stats = { str=20, dex=8, mag=6, con=16 },
	power_source = {technique=true},
}

newEntity{ base = "BASE_NPC_HUMAN_WARRIOR",
	name = "human guard", color=colors.LIGHT_UMBER,
	desc = [[A human guard.]],
	level_range = {1, nil}, exp_worth = 1,
	rarity = 1,
	max_life = resolvers.rngavg(80,90), life_rating = 11,
	resolvers.equip{
		{type="weapon", subtype="longsword", autoreq=true},
		{type="armor", subtype="shield", autoreq=true},
	},
	combat_armor = 0, combat_def = 6,
	resolvers.talents{ [Talents.T_SHIELD_PUMMEL]={base=1, every=10, max=5}, },
	seen_by = function(self, who)
		if not game.party:hasMember(who) or rng.percent(40) then return end
		self.seen_by = nil
		local race = string.lower(game.player.descriptor.race)
		local possesive = "Its"
		local noun ="It"
		local pronoun = "It"
		if game.player.descriptor.sex=="Female" then
			possesive = "Her"
			pronoun = "Her"
			noun = "She"
		end
		if game.player.descriptor.sex=="Male" then
			possesive="His"
			pronoun="Him"
			noun="He"
		end
		local emotes = {"Get "..string.lower(pronoun).."!", noun.." should not be here!", "What are you doing here?","Attack!", "Get "..string.lower(pronoun).."!", "This is going to hurt!", "How did you find us?", "Let's make sure "..string.lower(noun).." doesn't tell", "Slit "..string.lower(possesive).." throat!" , "Why can't we all be friends?" , " I did not sign up for this.", "Who are you?" , "Kill "..string.lower(noun).." first, ask questions later", "Kill the "..game.player.descriptor.race..", now!", noun.." must die!", possesive.." armor is so shiny!" , "I love cookies! Let's take "..string.lower(possesive).."cookies."}
		local randomemote = rng.table(emotes)

		self:doEmote(randomemote, 60)
	end,
}

